@@ -23,8 +23,10 @@ from .literals import (
     DeploymentUpdateTypeType,
     EnvironmentAccountConnectionRequesterAccountTypeType,
     EnvironmentAccountConnectionStatusType,
+    ListServiceInstancesSortByType,
     RepositoryProviderType,
     ResourceDeploymentStatusType,
+    SortOrderType,
     TemplateTypeType,
     TemplateVersionStatusType,
 )
@@ -105,6 +107,7 @@ from .type_defs import (
     ListRepositorySyncDefinitionsOutputTypeDef,
     ListServiceInstanceOutputsOutputTypeDef,
     ListServiceInstanceProvisionedResourcesOutputTypeDef,
+    ListServiceInstancesFilterTypeDef,
     ListServiceInstancesOutputTypeDef,
     ListServicePipelineOutputsOutputTypeDef,
     ListServicePipelineProvisionedResourcesOutputTypeDef,
@@ -285,6 +288,7 @@ class ProtonClient(BaseClient):
         spec: str,
         templateMajorVersion: str,
         templateName: str,
+        codebuildRoleArn: str = ...,
         componentRoleArn: str = ...,
         description: str = ...,
         environmentAccountConnectionId: str = ...,
@@ -307,6 +311,7 @@ class ProtonClient(BaseClient):
         managementAccountId: str,
         roleArn: str,
         clientToken: str = ...,
+        codebuildRoleArn: str = ...,
         componentRoleArn: str = ...,
         tags: Sequence[TagTypeDef] = ...
     ) -> CreateEnvironmentAccountConnectionOutputTypeDef:
@@ -843,7 +848,14 @@ class ProtonClient(BaseClient):
         """
 
     def list_service_instances(
-        self, *, maxResults: int = ..., nextToken: str = ..., serviceName: str = ...
+        self,
+        *,
+        filters: Sequence[ListServiceInstancesFilterTypeDef] = ...,
+        maxResults: int = ...,
+        nextToken: str = ...,
+        serviceName: str = ...,
+        sortBy: ListServiceInstancesSortByType = ...,
+        sortOrder: SortOrderType = ...
     ) -> ListServiceInstancesOutputTypeDef:
         """
         List service instances with summary data.
@@ -921,9 +933,9 @@ class ProtonClient(BaseClient):
         self,
         *,
         resourceArn: str,
-        status: ResourceDeploymentStatusType,
         deploymentId: str = ...,
         outputs: Sequence[OutputTypeDef] = ...,
+        status: ResourceDeploymentStatusType = ...,
         statusMessage: str = ...
     ) -> Dict[str, Any]:
         """
@@ -965,6 +977,7 @@ class ProtonClient(BaseClient):
         self,
         *,
         deletePipelineProvisioningRepository: bool = ...,
+        pipelineCodebuildRoleArn: str = ...,
         pipelineProvisioningRepository: RepositoryBranchInputTypeDef = ...,
         pipelineServiceRoleArn: str = ...
     ) -> UpdateAccountSettingsOutputTypeDef:
@@ -999,6 +1012,7 @@ class ProtonClient(BaseClient):
         *,
         deploymentType: DeploymentUpdateTypeType,
         name: str,
+        codebuildRoleArn: str = ...,
         componentRoleArn: str = ...,
         description: str = ...,
         environmentAccountConnectionId: str = ...,
@@ -1016,7 +1030,12 @@ class ProtonClient(BaseClient):
         """
 
     def update_environment_account_connection(
-        self, *, id: str, componentRoleArn: str = ..., roleArn: str = ...
+        self,
+        *,
+        id: str,
+        codebuildRoleArn: str = ...,
+        componentRoleArn: str = ...,
+        roleArn: str = ...
     ) -> UpdateEnvironmentAccountConnectionOutputTypeDef:
         """
         In an environment account, update an environment account connection to use a new
