@@ -42,7 +42,9 @@ __all__ = (
     "ListRepositorySyncDefinitionsPaginatorName",
     "ListServiceInstanceOutputsPaginatorName",
     "ListServiceInstanceProvisionedResourcesPaginatorName",
+    "ListServiceInstancesFilterByType",
     "ListServiceInstancesPaginatorName",
+    "ListServiceInstancesSortByType",
     "ListServicePipelineOutputsPaginatorName",
     "ListServicePipelineProvisionedResourcesPaginatorName",
     "ListServiceTemplateVersionsPaginatorName",
@@ -63,6 +65,7 @@ __all__ = (
     "ServiceTemplateSupportedComponentSourceTypeType",
     "ServiceTemplateVersionRegisteredWaiterName",
     "ServiceUpdatedWaiterName",
+    "SortOrderType",
     "SyncTypeType",
     "TemplateTypeType",
     "TemplateVersionStatusType",
@@ -110,7 +113,28 @@ ListServiceInstanceOutputsPaginatorName = Literal["list_service_instance_outputs
 ListServiceInstanceProvisionedResourcesPaginatorName = Literal[
     "list_service_instance_provisioned_resources"
 ]
+ListServiceInstancesFilterByType = Literal[
+    "createdAtAfter",
+    "createdAtBefore",
+    "deployedTemplateVersionStatus",
+    "deploymentStatus",
+    "environmentName",
+    "lastDeploymentAttemptedAtAfter",
+    "lastDeploymentAttemptedAtBefore",
+    "name",
+    "serviceName",
+    "templateName",
+]
 ListServiceInstancesPaginatorName = Literal["list_service_instances"]
+ListServiceInstancesSortByType = Literal[
+    "createdAt",
+    "deploymentStatus",
+    "environmentName",
+    "lastDeploymentAttemptedAt",
+    "name",
+    "serviceName",
+    "templateName",
+]
 ListServicePipelineOutputsPaginatorName = Literal["list_service_pipeline_outputs"]
 ListServicePipelineProvisionedResourcesPaginatorName = Literal[
     "list_service_pipeline_provisioned_resources"
@@ -148,6 +172,7 @@ ServiceStatusType = Literal[
 ServiceTemplateSupportedComponentSourceTypeType = Literal["DIRECTLY_DEFINED"]
 ServiceTemplateVersionRegisteredWaiterName = Literal["service_template_version_registered"]
 ServiceUpdatedWaiterName = Literal["service_updated"]
+SortOrderType = Literal["ASCENDING", "DESCENDING"]
 SyncTypeType = Literal["TEMPLATE_SYNC"]
 TemplateTypeType = Literal["ENVIRONMENT", "SERVICE"]
 TemplateVersionStatusType = Literal[
@@ -402,6 +427,7 @@ ServiceName = Literal[
     "redshift-serverless",
     "rekognition",
     "resiliencehub",
+    "resource-explorer-2",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -422,6 +448,7 @@ ServiceName = Literal[
     "sagemaker-featurestore-runtime",
     "sagemaker-runtime",
     "savingsplans",
+    "scheduler",
     "schemas",
     "sdb",
     "secretsmanager",
@@ -444,6 +471,7 @@ ServiceName = Literal[
     "ssm",
     "ssm-contacts",
     "ssm-incidents",
+    "ssmsap",
     "sso",
     "sso-admin",
     "sso-oidc",
