@@ -21,12 +21,15 @@ from .literals import (
     DeploymentUpdateTypeType,
     EnvironmentAccountConnectionRequesterAccountTypeType,
     EnvironmentAccountConnectionStatusType,
+    ListServiceInstancesFilterByType,
+    ListServiceInstancesSortByType,
     ProvisionedResourceEngineType,
     RepositoryProviderType,
     RepositorySyncStatusType,
     ResourceDeploymentStatusType,
     ResourceSyncStatusType,
     ServiceStatusType,
+    SortOrderType,
     TemplateTypeType,
     TemplateVersionStatusType,
 )
@@ -111,7 +114,7 @@ __all__ = (
     "RepositorySyncDefinitionTypeDef",
     "ListServiceInstanceOutputsInputRequestTypeDef",
     "ListServiceInstanceProvisionedResourcesInputRequestTypeDef",
-    "ListServiceInstancesInputRequestTypeDef",
+    "ListServiceInstancesFilterTypeDef",
     "ServiceInstanceSummaryTypeDef",
     "ListServicePipelineOutputsInputRequestTypeDef",
     "ListServicePipelineProvisionedResourcesInputRequestTypeDef",
@@ -216,7 +219,6 @@ __all__ = (
     "ListRepositorySyncDefinitionsInputListRepositorySyncDefinitionsPaginateTypeDef",
     "ListServiceInstanceOutputsInputListServiceInstanceOutputsPaginateTypeDef",
     "ListServiceInstanceProvisionedResourcesInputListServiceInstanceProvisionedResourcesPaginateTypeDef",
-    "ListServiceInstancesInputListServiceInstancesPaginateTypeDef",
     "ListServicePipelineOutputsInputListServicePipelineOutputsPaginateTypeDef",
     "ListServicePipelineProvisionedResourcesInputListServicePipelineProvisionedResourcesPaginateTypeDef",
     "ListServiceTemplateVersionsInputListServiceTemplateVersionsPaginateTypeDef",
@@ -234,6 +236,8 @@ __all__ = (
     "ListServicePipelineProvisionedResourcesOutputTypeDef",
     "ListRepositoriesOutputTypeDef",
     "ListRepositorySyncDefinitionsOutputTypeDef",
+    "ListServiceInstancesInputListServiceInstancesPaginateTypeDef",
+    "ListServiceInstancesInputRequestTypeDef",
     "ListServiceInstancesOutputTypeDef",
     "ListServiceTemplateVersionsOutputTypeDef",
     "ListServiceTemplatesOutputTypeDef",
@@ -286,6 +290,7 @@ _RequiredEnvironmentAccountConnectionTypeDef = TypedDict(
 _OptionalEnvironmentAccountConnectionTypeDef = TypedDict(
     "_OptionalEnvironmentAccountConnectionTypeDef",
     {
+        "codebuildRoleArn": str,
         "componentRoleArn": str,
     },
     total=False,
@@ -1267,12 +1272,11 @@ class ListServiceInstanceProvisionedResourcesInputRequestTypeDef(
     pass
 
 
-ListServiceInstancesInputRequestTypeDef = TypedDict(
-    "ListServiceInstancesInputRequestTypeDef",
+ListServiceInstancesFilterTypeDef = TypedDict(
+    "ListServiceInstancesFilterTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
-        "serviceName": str,
+        "key": ListServiceInstancesFilterByType,
+        "value": str,
     },
     total=False,
 )
@@ -1601,6 +1605,7 @@ _RequiredUpdateEnvironmentAccountConnectionInputRequestTypeDef = TypedDict(
 _OptionalUpdateEnvironmentAccountConnectionInputRequestTypeDef = TypedDict(
     "_OptionalUpdateEnvironmentAccountConnectionInputRequestTypeDef",
     {
+        "codebuildRoleArn": str,
         "componentRoleArn": str,
         "roleArn": str,
     },
@@ -1836,6 +1841,7 @@ UpdateEnvironmentAccountConnectionOutputTypeDef = TypedDict(
 AccountSettingsTypeDef = TypedDict(
     "AccountSettingsTypeDef",
     {
+        "pipelineCodebuildRoleArn": str,
         "pipelineProvisioningRepository": RepositoryBranchTypeDef,
         "pipelineServiceRoleArn": str,
     },
@@ -1859,6 +1865,7 @@ _RequiredEnvironmentTypeDef = TypedDict(
 _OptionalEnvironmentTypeDef = TypedDict(
     "_OptionalEnvironmentTypeDef",
     {
+        "codebuildRoleArn": str,
         "componentRoleArn": str,
         "deploymentStatusMessage": str,
         "description": str,
@@ -2095,6 +2102,7 @@ _OptionalCreateEnvironmentAccountConnectionInputRequestTypeDef = TypedDict(
     "_OptionalCreateEnvironmentAccountConnectionInputRequestTypeDef",
     {
         "clientToken": str,
+        "codebuildRoleArn": str,
         "componentRoleArn": str,
         "tags": Sequence[TagTypeDef],
     },
@@ -2243,6 +2251,7 @@ _RequiredCreateEnvironmentInputRequestTypeDef = TypedDict(
 _OptionalCreateEnvironmentInputRequestTypeDef = TypedDict(
     "_OptionalCreateEnvironmentInputRequestTypeDef",
     {
+        "codebuildRoleArn": str,
         "componentRoleArn": str,
         "description": str,
         "environmentAccountConnectionId": str,
@@ -2265,6 +2274,7 @@ UpdateAccountSettingsInputRequestTypeDef = TypedDict(
     "UpdateAccountSettingsInputRequestTypeDef",
     {
         "deletePipelineProvisioningRepository": bool,
+        "pipelineCodebuildRoleArn": str,
         "pipelineProvisioningRepository": RepositoryBranchInputTypeDef,
         "pipelineServiceRoleArn": str,
     },
@@ -2281,6 +2291,7 @@ _RequiredUpdateEnvironmentInputRequestTypeDef = TypedDict(
 _OptionalUpdateEnvironmentInputRequestTypeDef = TypedDict(
     "_OptionalUpdateEnvironmentInputRequestTypeDef",
     {
+        "codebuildRoleArn": str,
         "componentRoleArn": str,
         "description": str,
         "environmentAccountConnectionId": str,
@@ -2964,15 +2975,6 @@ class ListServiceInstanceProvisionedResourcesInputListServiceInstanceProvisioned
     pass
 
 
-ListServiceInstancesInputListServiceInstancesPaginateTypeDef = TypedDict(
-    "ListServiceInstancesInputListServiceInstancesPaginateTypeDef",
-    {
-        "serviceName": str,
-        "PaginationConfig": PaginatorConfigTypeDef,
-    },
-    total=False,
-)
-
 _RequiredListServicePipelineOutputsInputListServicePipelineOutputsPaginateTypeDef = TypedDict(
     "_RequiredListServicePipelineOutputsInputListServicePipelineOutputsPaginateTypeDef",
     {
@@ -3118,7 +3120,6 @@ _RequiredNotifyResourceDeploymentStatusChangeInputRequestTypeDef = TypedDict(
     "_RequiredNotifyResourceDeploymentStatusChangeInputRequestTypeDef",
     {
         "resourceArn": str,
-        "status": ResourceDeploymentStatusType,
     },
 )
 _OptionalNotifyResourceDeploymentStatusChangeInputRequestTypeDef = TypedDict(
@@ -3126,6 +3127,7 @@ _OptionalNotifyResourceDeploymentStatusChangeInputRequestTypeDef = TypedDict(
     {
         "deploymentId": str,
         "outputs": Sequence[OutputTypeDef],
+        "status": ResourceDeploymentStatusType,
         "statusMessage": str,
     },
     total=False,
@@ -3193,6 +3195,31 @@ ListRepositorySyncDefinitionsOutputTypeDef = TypedDict(
     },
 )
 
+ListServiceInstancesInputListServiceInstancesPaginateTypeDef = TypedDict(
+    "ListServiceInstancesInputListServiceInstancesPaginateTypeDef",
+    {
+        "filters": Sequence[ListServiceInstancesFilterTypeDef],
+        "serviceName": str,
+        "sortBy": ListServiceInstancesSortByType,
+        "sortOrder": SortOrderType,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+ListServiceInstancesInputRequestTypeDef = TypedDict(
+    "ListServiceInstancesInputRequestTypeDef",
+    {
+        "filters": Sequence[ListServiceInstancesFilterTypeDef],
+        "maxResults": int,
+        "nextToken": str,
+        "serviceName": str,
+        "sortBy": ListServiceInstancesSortByType,
+        "sortOrder": SortOrderType,
+    },
+    total=False,
+)
+
 ListServiceInstancesOutputTypeDef = TypedDict(
     "ListServiceInstancesOutputTypeDef",
     {
